@@ -47,6 +47,10 @@ class MailChimpListerError(Exception):
     """Simple exception type for handling errors with MailChimpLister"""
 
 
+class ServiceRunnerError(Exception):
+    """Simple exception type for handling errors with the service runners"""
+
+
 """
 CONS3RT command-line interface exceptions
 """
@@ -142,6 +146,10 @@ class EC2UtilError(Exception):
     """There was a problem with an AWS EC2 operation"""
 
 
+class ElbUtilError(Exception):
+    """There was a problem with an AWS EC2 operation"""
+
+
 class ImageUtilError(Exception):
     """There was a problem with an AWS AMI operation"""
 
